//+------------------------------------------------------------------+
//|                                                        Trade.mqh |
//|                                                  ©2025, UKwinika |
//|                                   https://t.me/TradersConnection |
//| Provides simplified trading functions for Expert Advisors        |
//+------------------------------------------------------------------+

#property copyright "2025, UKwinika"
#property link      "https://t.me/TradersConnection"

#ifndef TRADE_MQH
#define TRADE_MQH

//+------------------------------------------------------------------+
//| CTrade Class Definition                                          |
//+------------------------------------------------------------------+
class CTrade {
private:
   string   m_symbol;       // Symbol to trade
   double   m_lotSize;      // Default lot size
   int      m_slippage;     // Slippage in points
   double   m_stopLoss;     // Stop-loss in points
   double   m_takeProfit;   // Take-profit in points

public:
   // Constructor
   CTrade() {
      m_symbol      = Symbol();
      m_lotSize     = 0.1;    // Default lot size
      m_slippage    = 3;      // Default slippage
      m_stopLoss    = 0;      // No default SL
      m_takeProfit  = 0;      // No default TP
   }

   // Setters
   void SetSymbol(string symbol)      { m_symbol = symbol; }
   void SetLotSize(double lots)       { m_lotSize = lots; }
   void SetSlippage(int slippage)     { m_slippage = slippage; }
   void SetStopLoss(double sl)        { m_stopLoss = sl; }
   void SetTakeProfit(double tp)      { m_takeProfit = tp; }

   // Open a Buy order
   int Buy(double volume = 0, double sl = 0, double tp = 0, string comment = "") {
      double lot = (volume > 0) ? volume : m_lotSize;
      double stopLoss = (sl > 0) ? NormalizeDouble(Ask - sl * Point, Digits) : 0;
      double takeProfit = (tp > 0) ? NormalizeDouble(Ask + tp * Point, Digits) : 0;

      int ticket = OrderSend(m_symbol, OP_BUY, lot, Ask, m_slippage, 
                            stopLoss, takeProfit, comment, 0, 0, clrGreen);
      if (ticket < 0) {
         Print("Buy OrderSend failed with error #", GetLastError());
      }
      return ticket;
   }

   // Open a Sell order
   int Sell(double volume = 0, double sl = 0, double tp = 0, string comment = "") {
      double lot = (volume > 0) ? volume : m_lotSize;
      double stopLoss = (sl > 0) ? NormalizeDouble(Bid + sl * Point, Digits) : 0;
      double takeProfit = (tp > 0) ? NormalizeDouble(Bid - tp * Point, Digits) : 0;

      int ticket = OrderSend(m_symbol, OP_SELL, lot, Bid, m_slippage, 
                            stopLoss, takeProfit, comment, 0, 0, clrRed);
      if (ticket < 0) {
         Print("Sell OrderSend failed with error #", GetLastError());
      }
      return ticket;
   }

   // Close an order by ticket
   bool Close(int ticket) {
      bool success = false;  // Declare success once at the function level

      if (!OrderSelect(ticket, SELECT_BY_TICKET)) {
         Print("OrderSelect failed with error #", GetLastError());
         return false;
      }

      if (OrderType() == OP_BUY) {
         success = OrderClose(ticket, OrderLots(), Bid, m_slippage, clrYellow);
         if (!success) {
            Print("Close Buy failed with error #", GetLastError());
         }
         return success;
      } else if (OrderType() == OP_SELL) {
         success = OrderClose(ticket, OrderLots(), Ask, m_slippage, clrYellow);
         if (!success) {
            Print("Close Sell failed with error #", GetLastError());
         }
         return success;
      }
      return false;
   }

   // Modify an order's SL/TP
   bool Modify(int ticket, double sl, double tp) {
      if (!OrderSelect(ticket, SELECT_BY_TICKET)) {
         Print("OrderSelect failed with error #", GetLastError());
         return false;
      }

      double price = (OrderType() == OP_BUY) ? Ask : Bid;
      double stopLoss = (sl > 0) ? NormalizeDouble(price - sl * Point, Digits) : OrderStopLoss();
      double takeProfit = (tp > 0) ? NormalizeDouble(price + tp * Point, Digits) : OrderTakeProfit();

bool success = OrderModify(ticket, OrderOpenPrice(), stopLoss, takeProfit, 0, clrBlue);
      if (!success) {
         Print("OrderModify failed with error #", GetLastError());
      }
      return success;
   }
};

#endif
//+------------------------------------------------------------------+